import os

from rostran.core.settings import RULES_DIR

TF_RULES_DIR = os.path.join(RULES_DIR, "terraform")
TF_ALI_RULES_DIR = os.path.join(TF_RULES_DIR, "alicloud")
CF_RULES_DIR = os.path.join(RULES_DIR, "cloudformation")
CF_RESOURCE_RULES_DIR = os.path.join(CF_RULES_DIR, "resource")

TF_ALI_ROS_PROP_MAPPINGS = {
    "*": {
        "availability_zone": "ZoneId",
        "data_disks": "DiskMappings",
        "security_group": "SecurityGroupIds",
        "vswitch_id": "VSwitchId",
        "vswitch_name": "VSwitchName",
        "userdata": "UserData",
    },
    "alicloud_instance": {
        "key_name": "KeyPairName",
        "allocate_public_ip": "AllocatePublicIP",
        "data_disks.*.name": "DiskName",
    },
    "alicloud_actiontrail_trail": {
        "event_rw": "EventRW",
    },
    "alicloud_alidns_record": {"rr": "RR"},
    "alicloud_api_gateway_api": {
        "constant_parameters": "ConstParameters",
        "name": "ApiName",
        "request_parameters.*.in": "Location",
        "request_parameters.*.name": "ApiParameterName",
        "request_parameters.*.type": "ParameterType",
        "system_parameters.*.in": "Location",
        "system_parameters.*.name": "ParameterName",
        "system_parameters.*.name_service": "ServiceParameterName",
        "fc_service_config": "FunctionComputeConfig",
        "request_config": "RequestConfig",
    },
    "alicloud_api_gateway_app": {
        "name": "AppName",
    },
    "alicloud_slb_acl": {"entry_list": "AclEntries"},
}

TF_ALI_ROS_GENERATE_MAPPING = {
    "alicloud_actiontrail_trail": "ALIYUN::ACTIONTRAIL::Trail",
    "alicloud_alidns_domain": "ALIYUN::DNS::Domain",
    "alicloud_alidns_domain_group": "ALIYUN::DNS::DomainGroup",
    "alicloud_alidns_record": "ALIYUN::DNS::DomainRecord",
    "alicloud_alikafka_topic": "ALIYUN::KAFKA::Topic",
    "alicloud_api_gateway_api": "ALIYUN::ApiGateway::Api",
    "alicloud_api_gateway_app": "ALIYUN::ApiGateway::App",
    "alicloud_api_gateway_app_attachment": "ALIYUN::ApiGateway::Authorization",
    "alicloud_api_gateway_group": "ALIYUN::ApiGateway::Group",
    "alicloud_cdn_domain": "ALIYUN::CDN::Domain",
    "alicloud_cdn_domain_config": "ALIYUN::CDN::DomainConfig",
    "alicloud_cen_bandwidth_limit": "ALIYUN::CEN::CenBandwidthLimit",
    "alicloud_cen_bandwidth_package": "ALIYUN::CEN::CenBandwidthPackage",
    "alicloud_cen_bandwidth_package_attachment": "ALIYUN::CEN::CenBandwidthPackageAssociation",
    "alicloud_cen_instance": "ALIYUN::CEN::CenInstance",
    "alicloud_cen_instance_attachment": "ALIYUN::CEN::CenInstanceAttachment",
    "alicloud_common_bandwidth_package": "ALIYUN::VPC::CommonBandwidthPackage",
    "alicloud_common_bandwidth_package_attachment": "ALIYUN::VPC::CommonBandwidthPackageIp",
    "alicloud_cr_ee_repo": "ALIYUN::CR::Repository",
    "alicloud_cr_namespace": "ALIYUN::CR::Namespace",
    "alicloud_cr_repo": "ALIYUN::CR::Repository",
    "alicloud_cs_kubernetes": "ALIYUN::CS::KubernetesCluster",
    "alicloud_cs_managed_kubernetes": "ALIYUN::CS::ManagedKubernetesCluster",
    "alicloud_cs_serverless_kubernetes": "ALIYUN::CS::ServerlessKubernetesCluster",
    "alicloud_datahub_project": "ALIYUN::DATAHUB::Project",
    "alicloud_datahub_topic": "ALIYUN::DATAHUB::Topic",
    "alicloud_db_account_privilege": "ALIYUN::RDS::AccountPrivilege",
    "alicloud_db_database": "ALIYUN::RDS::Database",
    "alicloud_db_instance": "ALIYUN::RDS::DBInstance",
    "alicloud_db_readonly_instance": "ALIYUN::RDS::ReadOnlyDBInstance",
    "alicloud_dms_enterprise_instance": "ALIYUN::DMS::Instance",
    "alicloud_drds_instance": "ALIYUN::DRDS::DrdsInstance",
    "alicloud_eci_image_cache": "ALIYUN::ECI::ImageCache",
    "alicloud_ecs_activation": "ALIYUN::ECS::Activation",
    "alicloud_ecs_auto_snapshot_policy": "ALIYUN::ECS::AutoSnapshotPolicy",
    "alicloud_ecs_command": "ALIYUN::ECS::Command",
    "alicloud_ecs_dedicated_host": "ALIYUN::ECS::DedicatedHost",
    "alicloud_ecs_deployment_set": "ALIYUN::ECS::DeploymentSet",
    "alicloud_ecs_disk": "ALIYUN::ECS::Disk",
    "alicloud_ecs_disk_attachment": "ALIYUN::ECS::DiskAttachment",
    "alicloud_ecs_hpc_cluster": "ALIYUN::ECS::HpcCluster",
    "alicloud_ecs_instance_set": "ALIYUN::ECS::InstanceGroup",
    "alicloud_ecs_invocation": "ALIYUN::ECS::Invocation",
    "alicloud_ecs_key_pair": "ALIYUN::ECS::SSHKeyPair",
    "alicloud_ecs_key_pair_attachment": "ALIYUN::ECS::SSHKeyPairAttachment",
    "alicloud_ecs_launch_template": "ALIYUN::ECS::LaunchTemplate",
    "alicloud_ecs_network_interface": "ALIYUN::ECS::NetworkInterface",
    "alicloud_ecs_network_interface_attachment": "ALIYUN::ECS::NetworkInterfaceAttachment",
    "alicloud_ecs_network_interface_permission": "ALIYUN::ECS::NetworkInterfacePermission",
    "alicloud_ecs_prefix_list": "ALIYUN::ECS::PrefixList",
    "alicloud_ecs_snapshot": "ALIYUN::ECS::Snapshot",
    "alicloud_edas_application": "ALIYUN::EDAS::Application",
    "alicloud_edas_cluster": "ALIYUN::EDAS::Cluster",
    "alicloud_edas_deploy_group": "ALIYUN::EDAS::DeployGroup",
    "alicloud_eip_address": "ALIYUN::VPC::EIP",
    "alicloud_eip_association": "ALIYUN::VPC::EIPAssociation",
    "alicloud_elasticsearch_instance": "ALIYUN::ElasticSearch::Instance",
    "alicloud_emr_cluster": "ALIYUN::EMR::Cluster",
    "alicloud_ess_alarm": "ALIYUN::ESS::AlarmTask",
    "alicloud_ess_lifecycle_hook": (
        "alicloud_ess_lifecyclehook",
        "ALIYUN::ESS::LifecycleHook",
    ),
    "alicloud_ess_scaling_configuration": "ALIYUN::ESS::ScalingConfiguration",
    "alicloud_ess_scaling_group": "ALIYUN::ESS::ScalingGroup",
    "alicloud_ess_scaling_rule": (
        "alicloud_ess_scalingrule",
        "ALIYUN::ESS::ScalingRule",
    ),
    "alicloud_ess_scheduled_task": "ALIYUN::ESS::ScheduledTask",
    "alicloud_fc_function": "ALIYUN::FC::Function",
    "alicloud_fc_service": "ALIYUN::FC::Service",
    "alicloud_fc_trigger": "ALIYUN::FC::Trigger",
    "alicloud_forward_entry": "ALIYUN::ECS::ForwardEntry",
    "alicloud_image": "ALIYUN::ECS::CustomImage",
    "alicloud_image_copy": "ALIYUN::ECS::CopyImage",
    "alicloud_instance": "ALIYUN::ECS::Instance",
    "alicloud_kms_alias": "ALIYUN::KMS::Alias",
    "alicloud_kms_key": "ALIYUN::KMS::Key",
    "alicloud_kvstore_instance": "ALIYUN::REDIS::Instance",
    "alicloud_log_machine_group": "ALIYUN::SLS::MachineGroup",
    "alicloud_log_project": "ALIYUN::SLS::Project",
    "alicloud_log_store": "ALIYUN::SLS::Logstore",
    "alicloud_log_store_index": "ALIYUN::SLS::Index",
    "alicloud_market_order": "ALIYUN::MarketPlace::Order",
    "alicloud_mns_queue": "ALIYUN::MNS::Queue",
    "alicloud_mns_topic": "ALIYUN::MNS::Topic",
    "alicloud_mns_topic_subscription": "ALIYUN::MNS::Subscription",
    "alicloud_mongodb_instance": "ALIYUN::MONGODB::Instance",
    "alicloud_mongodb_sharding_instance": "ALIYUN::MONGODB::ShardingInstance",
    "alicloud_nas_access_group": "ALIYUN::NAS::AccessGroup",
    "alicloud_nas_access_rule": "ALIYUN::NAS::AccessRule",
    "alicloud_nas_file_system": "ALIYUN::NAS::FileSystem",
    "alicloud_nas_mount_target": "ALIYUN::NAS::MountTarget",
    "alicloud_nat_gateway": "ALIYUN::ECS::NatGateway",
    "alicloud_oos_execution": "ALIYUN::OOS::Execution",
    "alicloud_oos_template": "ALIYUN::OOS::Template",
    "alicloud_oss_bucket": "ALIYUN::OSS::Bucket",
    "alicloud_ots_instance": "ALIYUN::OTS::Instance",
    "alicloud_ots_table": "ALIYUN::OTS::Table",
    "alicloud_polardb_account": "ALIYUN::POLARDB::Account",
    "alicloud_polardb_account_privilege": "ALIYUN::POLARDB::AccountPrivilege",
    "alicloud_polardb_cluster": "ALIYUN::POLARDB::DBCluster",
    "alicloud_polardb_database": "ALIYUN::POLARDB::DBInstance",
    "alicloud_polardb_endpoint": "ALIYUN::POLARDB::DBClusterEndpoint",
    "alicloud_polardb_endpoint_address": "ALIYUN::POLARDB::DBClusterEndpointAddress",
    "alicloud_pvtz_zone": "ALIYUN::PVTZ::Zone",
    "alicloud_pvtz_zone_record": "ALIYUN::PVTZ::ZoneRecord",
    "alicloud_ram_access_key": "ALIYUN::RAM::AccessKey",
    "alicloud_ram_group": "ALIYUN::RAM::Group",
    "alicloud_ram_role": "ALIYUN::RAM::Role",
    "alicloud_ram_role_policy_attachment": "ALIYUN::RAM::AttachPolicyToRole",
    "alicloud_ram_user": "ALIYUN::RAM::User",
    "alicloud_ram_user_policy_attachment": "ALIYUN::RAM::AttachPolicyToUser",
    "alicloud_rds_account": "ALIYUN::RDS::Account",
    "alicloud_resource_manager_resource_group": "ALIYUN::ResourceManager::ResourceGroup",
    "alicloud_route_table": "ALIYUN::VPC::RouteTable",
    "alicloud_route_table_attachment": "ALIYUN::VPC::RouteTableAssociation",
    "alicloud_router_interface": "ALIYUN::VPC::RouterInterface",
    "alicloud_router_interface_connection": "ALIYUN::VPC::PeeringRouterInterfaceConnection",
    "alicloud_sag_acl": "ALIYUN::SAG::ACL",
    "alicloud_sag_acl_rule": "ALIYUN::SAG::ACLRule",
    "alicloud_security_group": "ALIYUN::ECS::SecurityGroup",
    "alicloud_security_group_rule": "ALIYUN::ECS::SecurityGroupIngress",
    "alicloud_slb_acl": "ALIYUN::SLB::AccessControl",
    "alicloud_slb_attachment": "ALIYUN::SLB::BackendServerAttachment",
    "alicloud_slb_backend_server": "ALIYUN::SLB::BackendServerAttachment",
    "alicloud_slb_domain_extension": "ALIYUN::SLB::DomainExtension",
    "alicloud_slb_listener": "ALIYUN::SLB::Listener",
    "alicloud_slb_load_balancer": "ALIYUN::SLB::LoadBalancer",
    "alicloud_slb_master_slave_server_group": "ALIYUN::SLB::MasterSlaveServerGroup",
    "alicloud_slb_server_certificate": "ALIYUN::SLB::Certificate",
    "alicloud_slb_server_group": "ALIYUN::SLB::VServerGroup",
    "alicloud_snat_entry": "ALIYUN::ECS::SNatEntry",
    "alicloud_ssl_certificates_service_certificate": "ALIYUN::CAS::Certificate",
    "alicloud_ssl_vpn_client_cert": "ALIYUN::VPC::SslVpnClientCert",
    "alicloud_ssl_vpn_server": "ALIYUN::VPC::SslVpnServer",
    "alicloud_vpc": "ALIYUN::ECS::VPC",
    "alicloud_vpc_bgp_group": "ALIYUN::VPC::BgpGroup",
    "alicloud_vpc_bgp_network": "ALIYUN::VPC::BgpNetwork",
    "alicloud_vpc_bgp_peer": "ALIYUN::VPC::BgpPeer",
    "alicloud_vpc_dhcp_options_set": "ALIYUN::VPC::DhcpOptionsSet",
    "alicloud_vpc_dhcp_options_set_attachment": "ALIYUN::VPC::DhcpOptionsSetAttachment",
    "alicloud_vpc_flow_log": "ALIYUN::VPC::FlowLog",
    "alicloud_vpc_ha_vip": "ALIYUN::VPC::HaVip",
    "alicloud_vpc_ipv4_gateway": "ALIYUN::VPC::Ipv4Gateway",
    "alicloud_vpc_ipv6_gateway": "ALIYUN::VPC::Ipv6Gateway",
    "alicloud_vpc_ipv6_internet_bandwidth": "ALIYUN::VPC::Ipv6InternetBandwidth",
    "alicloud_vpc_nat_ip": "ALIYUN::VPC::NatIp",
    "alicloud_vpc_prefix_list": "ALIYUN::VPC::PrefixList",
    "alicloud_vpc_traffic_mirror_filter": "ALIYUN::VPC::TrafficMirrorFilter",
    "alicloud_vpc_traffic_mirror_session": "ALIYUN::VPC::TrafficMirrorSession",
    "alicloud_vpn_connection": "ALIYUN::VPC::VpnConnection",
    "alicloud_vswitch": "ALIYUN::ECS::VSwitch",
}
